package burp.vaycore.onescan.ui.widget;

import burp.vaycore.common.utils.ClassUtils;
import burp.vaycore.common.utils.StringUtils;
import burp.vaycore.common.utils.Utils;
import burp.vaycore.onescan.bean.CollectData;
import burp.vaycore.onescan.bean.TaskData;
import burp.vaycore.onescan.common.CollectFilter;
import burp.vaycore.onescan.common.L;
import java.awt.Component;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.LinkedHashSet;
import java.util.Vector;
import javax.swing.JComponent;
import javax.swing.JLabel;
import javax.swing.JMenuItem;
import javax.swing.JPopupMenu;
import javax.swing.JTable;
import javax.swing.table.AbstractTableModel;
import javax.swing.table.TableCellRenderer;
import javax.swing.table.TableRowSorter;

public class CollectTable extends JTable implements ActionListener {

   private final CollectTable.CollectTableModel mTableModel;
   private final TableRowSorter mTableRowSorter;


   public CollectTable(CollectTable.CollectTableModel tableModel) {
      if(tableModel == null) {
         throw new IllegalArgumentException("tableModel is null.");
      } else {
         this.mTableModel = tableModel;
         this.setModel(this.mTableModel);
         this.setAutoResizeMode(0);
         this.mTableRowSorter = new TableRowSorter(this.mTableModel);
         this.setRowSorter(this.mTableRowSorter);
         this.getTableHeader().setReorderingAllowed(false);
         this.initColumnWidth();
         this.initEvent();
      }
   }

   private void initColumnWidth() {
      this.setColumnWidth(0, 70);
      this.setColumnWidth(1, 150);
      this.setColumnWidth(2, 200);
   }

   private void setColumnWidth(int columnIndex, int width) {
      this.getColumnModel().getColumn(columnIndex).setPreferredWidth(width);
   }

   private void initEvent() {
      this.addMouseListener(new MouseAdapter() {
         public void mouseReleased(MouseEvent e) {
            if(e.getButton() == 3) {
               CollectTable.this.showPopupMenu(e.getX(), e.getY());
            }

         }
      });
   }

   private void showPopupMenu(int x, int y) {
      JPopupMenu menu = new JPopupMenu();

      for(int i = 1; i < this.mTableModel.getColumnCount(); ++i) {
         String columnName = this.mTableModel.getColumnName(i);
         this.addPopupMenuItem(menu, L.get("copy_selected_hint", new Object[]{columnName}), "copy-column-" + i);
      }

      menu.setLightWeightPopupEnabled(true);
      menu.show(this, x, y);
   }

   private void addPopupMenuItem(JPopupMenu menu, String name, String actionCommand) {
      JMenuItem item = new JMenuItem(name);
      item.setActionCommand(actionCommand);
      item.addActionListener(this);
      menu.add(item);
   }

   public void setRowFilter(CollectFilter filter) {
      this.mTableRowSorter.setRowFilter(filter);
   }

   public Component prepareRenderer(TableCellRenderer renderer, int row, int column) {
      try {
         JComponent e = (JComponent)super.prepareRenderer(renderer, row, column);
         if(e instanceof JLabel) {
            ((JLabel)e).setHorizontalAlignment(2);
         }

         return e;
      } catch (Exception var5) {
         return super.prepareRenderer(renderer, row, column);
      }
   }

   public void actionPerformed(ActionEvent e) {
      String action = e.getActionCommand();
      if(action.startsWith("copy-column-")) {
         String columnIndexStr = action.replace("copy-column-", "");
         int columnIndex = StringUtils.parseInt(columnIndexStr);
         int[] selectedRows = this.getSelectedRows();
         LinkedHashSet result = new LinkedHashSet(selectedRows.length);
         int[] value = selectedRows;
         int var8 = selectedRows.length;

         for(int var9 = 0; var9 < var8; ++var9) {
            int rowIndex = value[var9];
            int index = this.convertRowIndexToModel(rowIndex);
            String value1 = String.valueOf(this.mTableModel.getValueAt(index, columnIndex));
            if(!StringUtils.isEmpty(value1)) {
               result.add(value1);
            }
         }

         if(result.size() > 0) {
            String var13 = StringUtils.join(result, "\n");
            Utils.setSysClipboardText(var13);
         }

      }
   }

   public abstract static class CollectTableModel extends AbstractTableModel {

      private final Vector mColumnNames = new Vector();
      private final ArrayList mData = new ArrayList();


      public CollectTableModel() {
         this.initColumnNames();
      }

      private void initColumnNames() {
         this.mColumnNames.add(L.get("collect_table_columns.id"));
         this.mColumnNames.add(L.get("collect_table_columns.domain"));
         String[] columnNames = this.buildColumnNames();
         if(columnNames != null && columnNames.length > 0) {
            this.mColumnNames.addAll(Arrays.asList(columnNames));
         }
      }

      protected abstract String[] buildColumnNames();

      public void add(CollectData data) {
         if(data != null) {
            ArrayList var2 = this.mData;
            synchronized(this.mData) {
               int index = this.mData.size();
               data.setId(index);
               this.mData.add(data);
               this.fireTableRowsInserted(index, index);
            }
         }
      }

      public void setList(ArrayList list) {
         if(list != null) {
            this.mData.clear();
            this.mData.addAll(list);
            this.fireTableDataChanged();
         }
      }

      public synchronized void clearAll() {
         this.mData.clear();
         this.fireTableDataChanged();
      }

      public int getRowCount() {
         return this.mData.size();
      }

      public final int getColumnCount() {
         return this.mColumnNames.size();
      }

      public Object getValueAt(int rowIndex, int columnIndex) {
         CollectData data = (CollectData)this.mData.get(rowIndex);
         if(columnIndex < 2) {
            switch(columnIndex) {
            case 0:
               return Integer.valueOf(data.getId());
            case 1:
               return data.getDomain();
            default:
               return "";
            }
         } else {
            return this.buildItemValue(data.getData(), columnIndex - 2);
         }
      }

      protected abstract Object buildItemValue(Object var1, int var2);

      public Class getColumnClass(int columnIndex) {
         return ClassUtils.getTypeByFieldId(TaskData.class, columnIndex);
      }

      public final String getColumnName(int column) {
         return (String)this.mColumnNames.get(column);
      }
   }
}
